# harvest-indices
A python package to calculate harvest anomalies from historical harvest data.

## calculate harvest anomalies using three indices:

* traditional harvest indices THI (frequently used by central European farmers)
* Standardized Harvest Index SHI (that we developped to analyze the harvest data base cropdata.de 
* Relative Harvest Index RHI similar (as e.g. in Ben-Ari et al (2018) and Beillouin et al. (2020))
